@@ -11,14 +11,20 @@
 #' @param sp_N number of spline functions, note the true number will be sp_N +
 #' sp_deg.
 #' @param sp_deg degree of spline functions.
-#' @param max_t truncate the FID when longer than max_t to reduce time taken
+#' @param max_t truncate the FID when longer than max_t to reduce time taken,
+#' set to NULL to use the entire FID.
 #' @param basis_type may be one of "poly" or "spline".
+#' @param rescale_output rescale the bl_matched_spec and bl output to improve
+#' consistency between dynamic scans.
+#' @param phase_corr apply phase correction (in addition to frequency). TRUE by
+#' default.
 #' @return a list containing the corrected data; phase and shift values in units
 #' of degrees and Hz respectively.
 #' @export
 rats <- function(mrs_data, ref = NULL, xlim = c(4, 0.5), max_shift = 20,
                  p_deg = 2, sp_N = 2, sp_deg = 3, max_t = 0.2,
-                 basis_type = "poly") {
+                 basis_type = "poly", rescale_output = TRUE,
+                 phase_corr = TRUE) {
   
   # move mrs_data to the time-domain
   if (is_fd(mrs_data)) mrs_data <- fd2td(mrs_data)
@@ -83,10 +89,19 @@ rats <- function(mrs_data, ref = NULL, xlim = c(4, 0.5), max_shift = 20,
   t_orig <- rep(seconds(mrs_data), each = Nspec(mrs_data))
   t_array <- array(t_orig, dim = dim(mrs_data$data))
   shift_array <- array(shifts, dim = dim(mrs_data$data))
+  
+  if (!phase_corr) phases <- 0
+  
   phase_array <- array(phases, dim = dim(mrs_data$data))
   mod_array <- exp(2i * pi * t_array * shift_array + 1i * phase_array * pi / 180)
   mrs_data$data <- mrs_data$data * mod_array
  
+  # maintain original intensities for bl_matched_spec and bl output
+  if (!rescale_output) {
+    corr_spec <- scale_mrs_amp(corr_spec, 1 / amps)
+    bl_spec   <- scale_mrs_amp(bl_spec,   1 / amps)
+  }
+  
   # results 
   list(corrected = mrs_data, phases = -phases, shifts = -shifts, amps = amps,
        bl_matched_spec = corr_spec, bl = -bl_spec)
